=========
CHANGELOG
=========

0.1
---

* Initial release of Django ASK SDK extension package.


0.1.1
-----

This release contains the following changes :

- Fix setting the custom user agent on the skill instance, when initializing the handler.



1.0.0
-------

This release contains the following changes :
 
- Move the webservice adapters to GA.
